@@ -6,7 +6,7 @@ from .handlers import setup_handlers
 def _jupyter_labextension_paths():
     return [{
         "src": "labextension",
-        "dest": "jupyterlab_judge"
+        "dest": "jupyterlab-judge"
     }]
 
 
